@@ -1,12 +1,12 @@
 survSNP.power.table <-
 function(GHRs,ns,rafs,erates,pilm,lm,model,test,alpha,exactvar=FALSE,B=0,para=FALSE)
   {
-    grr<-raf<-n<-erate<-NULL
-    res=foreach(grr=GHRs,.combine=rbind)%:%
+    GHR<-raf<-n<-erate<-NULL
+    res=foreach(GHR=GHRs,.combine=rbind)%:%
       foreach(raf=rafs,.combine=rbind)%:%
         foreach(n=ns,.combine=rbind)%:%
-              foreach(erate=erates,.combine=rbind)%do%{
-                sim.snp.expsurv.power(GHR=grr,
+            foreach(erate=erates,.combine=rbind)%do%{
+                sim.snp.expsurv.power(GHR=GHR,
                                       B=B,
                                       n=n,
                                       raf=raf,
